EfiTimerGenerateSoftInterrupt

Type Alias EfiTimerGenerateSoftInterrupt 

pub type EfiTimerGenerateSoftInterrupt = extern "efiapi" fn(this: *mut Protocol) -> Status;
This function generates a soft timer interrupt. If the platform does not support soft timer interrupts, then EFI_UNSUPPORTED is returned. Otherwise, EFI_SUCCESS is returned. If a handler has been registered through the EFI_TIMER_ARCH_PROTOCOL.RegisterHandler() service, then a soft timer interrupt will be generated. If the timer interrupt is enabled when this service is called, then the registered handler will be invoked. The registered handler should not be able to distinguish a hardware-generated timer interrupt from a software-generated timer interrupt.

  • this - The EFI_TIMER_ARCH_PROTOCOL instance.
  • @retval - EFI_SUCCESS: The soft timer interrupt was generated.
  • @retval - EFI_UNSUPPORTED: The platform does not support the generation of soft timer interrupts.