TestRunner

Struct TestRunner 

pub struct TestRunner { /* private fields */ }
A component that runs all test cases marked with the #[patina_test] attribute when loaded by the DXE core.

Implementations

Source

impl TestRunner

pub fn with_filter(self, filter: &'static str) -> Self

Adds a filter that will reduce the tests ran to only those that contain the filter value in their test name.

The name is not just the test name, but also the module path. For example, if a test is defined in my_crate::tests, the name would be my_crate::tests::test_case.

This filter is case-sensitive. It can be called multiple times to add multiple filters.

pub fn debug_mode(self, debug_mode: bool) -> Self

Any log messages generated by the test case will be logged if this is set to true.

Defaults to false.

pub fn with_callback(self, callback: fn(&'static str, &'static str)) -> Self

Attach a callback function that will be called on test failure.

fn(test_name: &’static str, fail_msg: &’static str)