pub struct MemoryAttribute(/* private fields */);Expand description
Memory attributes as specified in the UEFI specification.
Used to describe the attributes of a memory region.
https://uefi.org/specs/UEFI/2.11/07_Services_Boot_Services.html#efi-boot-services-getmemorymap
Implementations
Sourceimpl MemoryAttribute
impl MemoryAttribute
Sourcepub const UC: MemoryAttribute
pub const UC: MemoryAttribute
Memory cacheability attribute: The memory region is not cacheable.
Sourcepub const WC: MemoryAttribute
pub const WC: MemoryAttribute
Memory cacheability attribute: The memory region is write combined.
Sourcepub const WT: MemoryAttribute
pub const WT: MemoryAttribute
Memory cacheability attribute: The memory region is cacheable with a “write through” policy. Writes that hit in the cache will also be written to main memory.
Sourcepub const WB: MemoryAttribute
pub const WB: MemoryAttribute
Memory cacheability attribute: The memory region is cacheable with a “write back” policy. Reads and writes that hit in the cache do not propagate to main memory. Dirty data is written back to main memory when a new cache line is allocated.
Sourcepub const UCE: MemoryAttribute
pub const UCE: MemoryAttribute
Memory cacheability attribute: The memory region is cacheable, exported, and supports the “fetch and add” semaphore mechanism.
Sourcepub const WP: MemoryAttribute
pub const WP: MemoryAttribute
Physical memory protection attribute: The memory region is write-protected by system hardware. This is typically used as a cacheability attribute today. The memory region is cacheable with a “write protected” policy. Reads come from cache lines when possible, and read misses cause cache fills. Writes are propagated to the system bus and cause corresponding cache lines on all processors on the bus to be invalidated.
Sourcepub const RP: MemoryAttribute
pub const RP: MemoryAttribute
Physical memory protection attribute: The memory region is read-protected by system hardware.
Sourcepub const XP: MemoryAttribute
pub const XP: MemoryAttribute
Physical memory protection attribute: The memory region supports is protected by system hardware from executing code.
Sourcepub const NV: MemoryAttribute
pub const NV: MemoryAttribute
Runtime memory attribute: The memory region refers to persistent memory
Sourcepub const MORE_RELIABLE: MemoryAttribute
pub const MORE_RELIABLE: MemoryAttribute
The memory region provides higher reliability relative to other memory in the system. If all memory has the same reliability, then this bit is not used.
Sourcepub const RO: MemoryAttribute
pub const RO: MemoryAttribute
Physical memory protection attribute: The memory region supports making this memory range read-only by system hardware.
Sourcepub const SP: MemoryAttribute
pub const SP: MemoryAttribute
Specific-purpose memory (SPM). The memory is earmarked for specific purposes such as for specific device drivers or applications. The SPM attribute serves as a hint to the OS to avoid allocating this memory for core OS data or code that can not be relocated. Prolonged use of this memory for purposes other than the intended purpose may result in suboptimal platform performance.
Sourcepub const CPU_CRYPTO: MemoryAttribute
pub const CPU_CRYPTO: MemoryAttribute
The memory region is protected with the CPU’s memory cryptographic capabilities. If this flag is clear, the memory region is not capable of being protected with the CPU’s memory cryptographic capabilities or the CPU does not support CPU memory cryptographic capabilities.
Sourcepub const RUNTIME: MemoryAttribute
pub const RUNTIME: MemoryAttribute
Runtime memory attribute: The memory region needs to be given a virtual mapping by the operating system when SetVirtualAddressMap() is called.
Sourcepub const ISA_VALID: MemoryAttribute
pub const ISA_VALID: MemoryAttribute
The memory region is described with additional ISA-specific memory attributes as specified in EFI_MEMORY_ISA_MASK.
Sourcepub const ISA_MASK: MemoryAttribute
pub const ISA_MASK: MemoryAttribute
Bits reserved for describing optional ISA-specific cacheability attributes that are not covered by the standard UEFI Memory Attributes cacheability bits (EFI_MEMORY_UC, EFI_MEMORY_WC, EFI_MEMORY_WT, EFI_MEMORY_WB and EFI_MEMORY_UCE). See Calling Conventions for further ISA-specific enumeration of these bits.