#[repr(u32)]pub enum EventTimerType {
Cancel = 0,
Periodic = 1,
Relative = 2,
}Expand description
The type of time that is specified in TriggerTime. See the timer delay types in “Related Definitions.”
Variants
Cancel = 0
The event’s timer setting is to be cancelled and no timer trigger is to be set. TriggerTime is ignored when canceling a timer.
Periodic = 1
The event is to be signaled periodically at TriggerTime intervals from the current time. This is the only timer trigger Type for which the event timer does not need to be reset for each notification. All other timer trigger types are “one shot.”
Relative = 2
The event is to be signaled in TriggerTime 100ns units.